#!/usr/bin/env python3

""" 
	This module provides a set of reuseable functions
	which provide the main app functionality.
	We could even go a stage further and separate
	database interactions from logic...
"""

from config import config
import utils

def home():
    """ The homepage functionality
    """
    print( utils.render_template( config['TEMPLATE_DIR'] + 'home.html') )
    return

def play_game(cursor, player_id):
    """ The game interface
        Initiates a new hangman game
        for the current user
    """
    # define query to fetch a random row from the Word table
    query = ("SELECT letters, hint FROM Word ORDER BY RAND() LIMIT 1")

    # execute the query
    cursor.execute(query)
    # if a word came back, output the game board
    for (letters, hint) in cursor:
        print( utils.render_template( config['TEMPLATE_DIR']+'hangman.html', data=[player_id, letters, hint, player_id] ) )

def record_game(cursor, form_data):
    """ Check for form submission
        and record game in database
    """
    # make a string based on won status
    if int(form_data['won'].value) == 0:
        game_status = 'loss'
    else:
        game_status = 'win'

    # define a query to insert a new row in Game table
    query = ("INSERT INTO Game (player_id, won, guessed_word) VALUES (%s, %s, %s)")
    
    # define data as tuple to replace tokens in query
    data = ( int(form_data['player_id'].value), int(form_data['won'].value), form_data['guessed_word'].value)

    # execute the query
    cursor.execute(query, data)

    # check if rows were produced
    if cursor.lastrowid:
        # output message
        print( utils.render_template( config['TEMPLATE_DIR']+'record-game.html', data=[game_status] ) )
    else:
        # the game was not recorded
        return False

def leaderboard(cursor):
    """ The leaderboard component
        #TODO: make it output the query results row by row
        in a for loop - a job for a `proper' template engine?
    """
    query = ("SELECT Player.username AS player, "
            "(SELECT COUNT(*) FROM Game WHERE Game.player_id=Player.id) AS num_plays, "
            "(SELECT COUNT(*) FROM Game WHERE Game.player_id=Player.id AND Game.won=1) AS num_wins "
            "FROM Player "
            "INNER JOIN Game ON Game.player_id=Player.id "
            "GROUP BY username "
            "ORDER BY num_wins/num_plays DESC")
    # execute the query
    cursor.execute(query)

    # check we got something back
    for (player, num_plays, num_wins) in cursor:
        print("<p>{} won {} of {} games</p>".format(player, str(num_wins), str(num_plays)))

    # finish this component...
    print( utils.render_template( config['TEMPLATE_DIR'] + 'leaderboard.html') )
    return
